# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetOperationsInsightsWarehousesResult',
    'AwaitableGetOperationsInsightsWarehousesResult',
    'get_operations_insights_warehouses',
    'get_operations_insights_warehouses_output',
]

@pulumi.output_type
class GetOperationsInsightsWarehousesResult:
    """
    A collection of values returned by getOperationsInsightsWarehouses.
    """
    def __init__(__self__, compartment_id=None, display_name=None, filters=None, id=None, operations_insights_warehouse_summary_collections=None, states=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if operations_insights_warehouse_summary_collections and not isinstance(operations_insights_warehouse_summary_collections, list):
            raise TypeError("Expected argument 'operations_insights_warehouse_summary_collections' to be a list")
        pulumi.set(__self__, "operations_insights_warehouse_summary_collections", operations_insights_warehouse_summary_collections)
        if states and not isinstance(states, list):
            raise TypeError("Expected argument 'states' to be a list")
        pulumi.set(__self__, "states", states)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        User-friedly name of Operations Insights Warehouse that does not have to be unique.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetOperationsInsightsWarehousesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        OPSI Warehouse OCID
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="operationsInsightsWarehouseSummaryCollections")
    def operations_insights_warehouse_summary_collections(self) -> Sequence['outputs.GetOperationsInsightsWarehousesOperationsInsightsWarehouseSummaryCollectionResult']:
        """
        The list of operations_insights_warehouse_summary_collection.
        """
        return pulumi.get(self, "operations_insights_warehouse_summary_collections")

    @property
    @pulumi.getter
    def states(self) -> Optional[Sequence[str]]:
        """
        Possible lifecycle states
        """
        return pulumi.get(self, "states")


class AwaitableGetOperationsInsightsWarehousesResult(GetOperationsInsightsWarehousesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOperationsInsightsWarehousesResult(
            compartment_id=self.compartment_id,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            operations_insights_warehouse_summary_collections=self.operations_insights_warehouse_summary_collections,
            states=self.states)


def get_operations_insights_warehouses(compartment_id: Optional[str] = None,
                                       display_name: Optional[str] = None,
                                       filters: Optional[Sequence[pulumi.InputType['GetOperationsInsightsWarehousesFilterArgs']]] = None,
                                       id: Optional[str] = None,
                                       states: Optional[Sequence[str]] = None,
                                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOperationsInsightsWarehousesResult:
    """
    This data source provides the list of Operations Insights Warehouses in Oracle Cloud Infrastructure Opsi service.

    Gets a list of Operations Insights warehouses. Either compartmentId or id must be specified.
    There is only expected to be 1 warehouse per tenant. The warehouse is expected to be in the root compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_operations_insights_warehouses = oci.Opsi.get_operations_insights_warehouses(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        states=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
    :param str display_name: A filter to return only resources that match the entire display name.
    :param str id: Unique Operations Insights Warehouse identifier
    :param Sequence[str] states: Lifecycle states
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['id'] = id
    __args__['states'] = states
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Opsi/getOperationsInsightsWarehouses:getOperationsInsightsWarehouses', __args__, opts=opts, typ=GetOperationsInsightsWarehousesResult).value

    return AwaitableGetOperationsInsightsWarehousesResult(
        compartment_id=__ret__.compartment_id,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        operations_insights_warehouse_summary_collections=__ret__.operations_insights_warehouse_summary_collections,
        states=__ret__.states)


@_utilities.lift_output_func(get_operations_insights_warehouses)
def get_operations_insights_warehouses_output(compartment_id: Optional[pulumi.Input[Optional[str]]] = None,
                                              display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                              filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetOperationsInsightsWarehousesFilterArgs']]]]] = None,
                                              id: Optional[pulumi.Input[Optional[str]]] = None,
                                              states: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetOperationsInsightsWarehousesResult]:
    """
    This data source provides the list of Operations Insights Warehouses in Oracle Cloud Infrastructure Opsi service.

    Gets a list of Operations Insights warehouses. Either compartmentId or id must be specified.
    There is only expected to be 1 warehouse per tenant. The warehouse is expected to be in the root compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_operations_insights_warehouses = oci.Opsi.get_operations_insights_warehouses(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        states=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
    :param str display_name: A filter to return only resources that match the entire display name.
    :param str id: Unique Operations Insights Warehouse identifier
    :param Sequence[str] states: Lifecycle states
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetChannelsResult',
    'AwaitableGetChannelsResult',
    'get_channels',
    'get_channels_output',
]

@pulumi.output_type
class GetChannelsResult:
    """
    A collection of values returned by getChannels.
    """
    def __init__(__self__, channel_id=None, channels=None, compartment_id=None, db_system_id=None, display_name=None, filters=None, id=None, is_enabled=None, state=None):
        if channel_id and not isinstance(channel_id, str):
            raise TypeError("Expected argument 'channel_id' to be a str")
        pulumi.set(__self__, "channel_id", channel_id)
        if channels and not isinstance(channels, list):
            raise TypeError("Expected argument 'channels' to be a list")
        pulumi.set(__self__, "channels", channels)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if db_system_id and not isinstance(db_system_id, str):
            raise TypeError("Expected argument 'db_system_id' to be a str")
        pulumi.set(__self__, "db_system_id", db_system_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_enabled and not isinstance(is_enabled, bool):
            raise TypeError("Expected argument 'is_enabled' to be a bool")
        pulumi.set(__self__, "is_enabled", is_enabled)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="channelId")
    def channel_id(self) -> Optional[str]:
        return pulumi.get(self, "channel_id")

    @property
    @pulumi.getter
    def channels(self) -> Sequence['outputs.GetChannelsChannelResult']:
        """
        The list of channels.
        """
        return pulumi.get(self, "channels")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="dbSystemId")
    def db_system_id(self) -> Optional[str]:
        """
        The OCID of the source DB System.
        """
        return pulumi.get(self, "db_system_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        The user-friendly name for the Channel. It does not have to be unique.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetChannelsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> Optional[bool]:
        """
        Whether the Channel has been enabled by the user.
        """
        return pulumi.get(self, "is_enabled")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The state of the Channel.
        """
        return pulumi.get(self, "state")


class AwaitableGetChannelsResult(GetChannelsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetChannelsResult(
            channel_id=self.channel_id,
            channels=self.channels,
            compartment_id=self.compartment_id,
            db_system_id=self.db_system_id,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            is_enabled=self.is_enabled,
            state=self.state)


def get_channels(channel_id: Optional[str] = None,
                 compartment_id: Optional[str] = None,
                 db_system_id: Optional[str] = None,
                 display_name: Optional[str] = None,
                 filters: Optional[Sequence[pulumi.InputType['GetChannelsFilterArgs']]] = None,
                 is_enabled: Optional[bool] = None,
                 state: Optional[str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetChannelsResult:
    """
    This data source provides the list of Channels in Oracle Cloud Infrastructure MySQL Database service.

    Lists all the Channels that match the specified filters.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_channels = oci.Mysql.get_channels(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        channel_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        db_system_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str channel_id: The OCID of the Channel.
    :param str compartment_id: The compartment [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str db_system_id: The DB System [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str display_name: A filter to return only the resource matching the given display name exactly.
    :param bool is_enabled: If true, returns only Channels that are enabled. If false, returns only Channels that are disabled.
    :param str state: The LifecycleState of the Channel.
    """
    __args__ = dict()
    __args__['channelId'] = channel_id
    __args__['compartmentId'] = compartment_id
    __args__['dbSystemId'] = db_system_id
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['isEnabled'] = is_enabled
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Mysql/getChannels:getChannels', __args__, opts=opts, typ=GetChannelsResult).value

    return AwaitableGetChannelsResult(
        channel_id=__ret__.channel_id,
        channels=__ret__.channels,
        compartment_id=__ret__.compartment_id,
        db_system_id=__ret__.db_system_id,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        is_enabled=__ret__.is_enabled,
        state=__ret__.state)


@_utilities.lift_output_func(get_channels)
def get_channels_output(channel_id: Optional[pulumi.Input[Optional[str]]] = None,
                        compartment_id: Optional[pulumi.Input[str]] = None,
                        db_system_id: Optional[pulumi.Input[Optional[str]]] = None,
                        display_name: Optional[pulumi.Input[Optional[str]]] = None,
                        filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetChannelsFilterArgs']]]]] = None,
                        is_enabled: Optional[pulumi.Input[Optional[bool]]] = None,
                        state: Optional[pulumi.Input[Optional[str]]] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetChannelsResult]:
    """
    This data source provides the list of Channels in Oracle Cloud Infrastructure MySQL Database service.

    Lists all the Channels that match the specified filters.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_channels = oci.Mysql.get_channels(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        channel_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        db_system_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str channel_id: The OCID of the Channel.
    :param str compartment_id: The compartment [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str db_system_id: The DB System [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str display_name: A filter to return only the resource matching the given display name exactly.
    :param bool is_enabled: If true, returns only Channels that are enabled. If false, returns only Channels that are disabled.
    :param str state: The LifecycleState of the Channel.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetSubscribedServicesResult',
    'AwaitableGetSubscribedServicesResult',
    'get_subscribed_services',
    'get_subscribed_services_output',
]

@pulumi.output_type
class GetSubscribedServicesResult:
    """
    A collection of values returned by getSubscribedServices.
    """
    def __init__(__self__, compartment_id=None, filters=None, id=None, order_line_id=None, status=None, subscribed_services=None, subscription_id=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if order_line_id and not isinstance(order_line_id, str):
            raise TypeError("Expected argument 'order_line_id' to be a str")
        pulumi.set(__self__, "order_line_id", order_line_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if subscribed_services and not isinstance(subscribed_services, list):
            raise TypeError("Expected argument 'subscribed_services' to be a list")
        pulumi.set(__self__, "subscribed_services", subscribed_services)
        if subscription_id and not isinstance(subscription_id, str):
            raise TypeError("Expected argument 'subscription_id' to be a str")
        pulumi.set(__self__, "subscription_id", subscription_id)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetSubscribedServicesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="orderLineId")
    def order_line_id(self) -> Optional[str]:
        """
        Sales Order Line Id associated to the subscribed service
        """
        return pulumi.get(self, "order_line_id")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        """
        Subscribed service status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subscribedServices")
    def subscribed_services(self) -> Sequence['outputs.GetSubscribedServicesSubscribedServiceResult']:
        """
        The list of subscribed_services.
        """
        return pulumi.get(self, "subscribed_services")

    @property
    @pulumi.getter(name="subscriptionId")
    def subscription_id(self) -> str:
        """
        Subscription ID associated to the subscribed service
        """
        return pulumi.get(self, "subscription_id")


class AwaitableGetSubscribedServicesResult(GetSubscribedServicesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSubscribedServicesResult(
            compartment_id=self.compartment_id,
            filters=self.filters,
            id=self.id,
            order_line_id=self.order_line_id,
            status=self.status,
            subscribed_services=self.subscribed_services,
            subscription_id=self.subscription_id)


def get_subscribed_services(compartment_id: Optional[str] = None,
                            filters: Optional[Sequence[pulumi.InputType['GetSubscribedServicesFilterArgs']]] = None,
                            order_line_id: Optional[str] = None,
                            status: Optional[str] = None,
                            subscription_id: Optional[str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSubscribedServicesResult:
    """
    This data source provides the list of Subscribed Services in Oracle Cloud Infrastructure Onesubscription service.

    This list API returns all subscribed services for given Subscription ID

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_subscribed_services = oci.OneSubsription.get_subscribed_services(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        subscription_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        order_line_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        status=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the root compartment.
    :param str order_line_id: Order Line identifier at subscribed service level . This identifier is originated in Order Management module. Default is null.
    :param str status: This param is used to filter subscribed services based on its status
    :param str subscription_id: Line level Subscription Id
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['filters'] = filters
    __args__['orderLineId'] = order_line_id
    __args__['status'] = status
    __args__['subscriptionId'] = subscription_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:OneSubsription/getSubscribedServices:getSubscribedServices', __args__, opts=opts, typ=GetSubscribedServicesResult).value

    return AwaitableGetSubscribedServicesResult(
        compartment_id=__ret__.compartment_id,
        filters=__ret__.filters,
        id=__ret__.id,
        order_line_id=__ret__.order_line_id,
        status=__ret__.status,
        subscribed_services=__ret__.subscribed_services,
        subscription_id=__ret__.subscription_id)


@_utilities.lift_output_func(get_subscribed_services)
def get_subscribed_services_output(compartment_id: Optional[pulumi.Input[str]] = None,
                                   filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetSubscribedServicesFilterArgs']]]]] = None,
                                   order_line_id: Optional[pulumi.Input[Optional[str]]] = None,
                                   status: Optional[pulumi.Input[Optional[str]]] = None,
                                   subscription_id: Optional[pulumi.Input[str]] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSubscribedServicesResult]:
    """
    This data source provides the list of Subscribed Services in Oracle Cloud Infrastructure Onesubscription service.

    This list API returns all subscribed services for given Subscription ID

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_subscribed_services = oci.OneSubsription.get_subscribed_services(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        subscription_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        order_line_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        status=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the root compartment.
    :param str order_line_id: Order Line identifier at subscribed service level . This identifier is originated in Order Management module. Default is null.
    :param str status: This param is used to filter subscribed services based on its status
    :param str subscription_id: Line level Subscription Id
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetIngressGatewayRouteTablesResult',
    'AwaitableGetIngressGatewayRouteTablesResult',
    'get_ingress_gateway_route_tables',
    'get_ingress_gateway_route_tables_output',
]

@pulumi.output_type
class GetIngressGatewayRouteTablesResult:
    """
    A collection of values returned by getIngressGatewayRouteTables.
    """
    def __init__(__self__, compartment_id=None, filters=None, id=None, ingress_gateway_id=None, ingress_gateway_route_table_collections=None, name=None, state=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ingress_gateway_id and not isinstance(ingress_gateway_id, str):
            raise TypeError("Expected argument 'ingress_gateway_id' to be a str")
        pulumi.set(__self__, "ingress_gateway_id", ingress_gateway_id)
        if ingress_gateway_route_table_collections and not isinstance(ingress_gateway_route_table_collections, list):
            raise TypeError("Expected argument 'ingress_gateway_route_table_collections' to be a list")
        pulumi.set(__self__, "ingress_gateway_route_table_collections", ingress_gateway_route_table_collections)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetIngressGatewayRouteTablesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        Unique identifier that is immutable on creation.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ingressGatewayId")
    def ingress_gateway_id(self) -> Optional[str]:
        """
        The OCID of the ingress gateway.
        """
        return pulumi.get(self, "ingress_gateway_id")

    @property
    @pulumi.getter(name="ingressGatewayRouteTableCollections")
    def ingress_gateway_route_table_collections(self) -> Sequence['outputs.GetIngressGatewayRouteTablesIngressGatewayRouteTableCollectionResult']:
        """
        The list of ingress_gateway_route_table_collection.
        """
        return pulumi.get(self, "ingress_gateway_route_table_collections")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Name of the ingress gateway host that this route should apply to.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the Resource.
        """
        return pulumi.get(self, "state")


class AwaitableGetIngressGatewayRouteTablesResult(GetIngressGatewayRouteTablesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIngressGatewayRouteTablesResult(
            compartment_id=self.compartment_id,
            filters=self.filters,
            id=self.id,
            ingress_gateway_id=self.ingress_gateway_id,
            ingress_gateway_route_table_collections=self.ingress_gateway_route_table_collections,
            name=self.name,
            state=self.state)


def get_ingress_gateway_route_tables(compartment_id: Optional[str] = None,
                                     filters: Optional[Sequence[pulumi.InputType['GetIngressGatewayRouteTablesFilterArgs']]] = None,
                                     id: Optional[str] = None,
                                     ingress_gateway_id: Optional[str] = None,
                                     name: Optional[str] = None,
                                     state: Optional[str] = None,
                                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIngressGatewayRouteTablesResult:
    """
    This data source provides the list of Ingress Gateway Route Tables in Oracle Cloud Infrastructure Service Mesh service.

    Returns a list of IngressGatewayRouteTable objects.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_ingress_gateway_route_tables = oci.ServiceMesh.get_ingress_gateway_route_tables(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        ingress_gateway_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The ID of the compartment in which to list resources.
    :param str id: Unique IngressGatewayRouteTable identifier.
    :param str ingress_gateway_id: Unique IngressGateway identifier.
    :param str name: A filter to return only resources that match the entire name given.
    :param str state: A filter to return only resources that match the life cycle state given.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['filters'] = filters
    __args__['id'] = id
    __args__['ingressGatewayId'] = ingress_gateway_id
    __args__['name'] = name
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:ServiceMesh/getIngressGatewayRouteTables:getIngressGatewayRouteTables', __args__, opts=opts, typ=GetIngressGatewayRouteTablesResult).value

    return AwaitableGetIngressGatewayRouteTablesResult(
        compartment_id=__ret__.compartment_id,
        filters=__ret__.filters,
        id=__ret__.id,
        ingress_gateway_id=__ret__.ingress_gateway_id,
        ingress_gateway_route_table_collections=__ret__.ingress_gateway_route_table_collections,
        name=__ret__.name,
        state=__ret__.state)


@_utilities.lift_output_func(get_ingress_gateway_route_tables)
def get_ingress_gateway_route_tables_output(compartment_id: Optional[pulumi.Input[str]] = None,
                                            filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetIngressGatewayRouteTablesFilterArgs']]]]] = None,
                                            id: Optional[pulumi.Input[Optional[str]]] = None,
                                            ingress_gateway_id: Optional[pulumi.Input[Optional[str]]] = None,
                                            name: Optional[pulumi.Input[Optional[str]]] = None,
                                            state: Optional[pulumi.Input[Optional[str]]] = None,
                                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetIngressGatewayRouteTablesResult]:
    """
    This data source provides the list of Ingress Gateway Route Tables in Oracle Cloud Infrastructure Service Mesh service.

    Returns a list of IngressGatewayRouteTable objects.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_ingress_gateway_route_tables = oci.ServiceMesh.get_ingress_gateway_route_tables(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        ingress_gateway_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The ID of the compartment in which to list resources.
    :param str id: Unique IngressGatewayRouteTable identifier.
    :param str ingress_gateway_id: Unique IngressGateway identifier.
    :param str name: A filter to return only resources that match the entire name given.
    :param str state: A filter to return only resources that match the life cycle state given.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetKeysResult',
    'AwaitableGetKeysResult',
    'get_keys',
    'get_keys_output',
]

@pulumi.output_type
class GetKeysResult:
    """
    A collection of values returned by getKeys.
    """
    def __init__(__self__, algorithm=None, compartment_id=None, curve_id=None, filters=None, id=None, keys=None, length=None, management_endpoint=None, protection_mode=None):
        if algorithm and not isinstance(algorithm, str):
            raise TypeError("Expected argument 'algorithm' to be a str")
        pulumi.set(__self__, "algorithm", algorithm)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if curve_id and not isinstance(curve_id, str):
            raise TypeError("Expected argument 'curve_id' to be a str")
        pulumi.set(__self__, "curve_id", curve_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if keys and not isinstance(keys, list):
            raise TypeError("Expected argument 'keys' to be a list")
        pulumi.set(__self__, "keys", keys)
        if length and not isinstance(length, int):
            raise TypeError("Expected argument 'length' to be a int")
        pulumi.set(__self__, "length", length)
        if management_endpoint and not isinstance(management_endpoint, str):
            raise TypeError("Expected argument 'management_endpoint' to be a str")
        pulumi.set(__self__, "management_endpoint", management_endpoint)
        if protection_mode and not isinstance(protection_mode, str):
            raise TypeError("Expected argument 'protection_mode' to be a str")
        pulumi.set(__self__, "protection_mode", protection_mode)

    @property
    @pulumi.getter
    def algorithm(self) -> Optional[str]:
        """
        The algorithm used by a key's key versions to encrypt or decrypt.
        """
        return pulumi.get(self, "algorithm")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment that contains this master encryption key.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="curveId")
    def curve_id(self) -> Optional[str]:
        """
        Supported curve IDs for ECDSA keys.
        """
        return pulumi.get(self, "curve_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetKeysFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def keys(self) -> Sequence['outputs.GetKeysKeyResult']:
        """
        The list of keys.
        """
        return pulumi.get(self, "keys")

    @property
    @pulumi.getter
    def length(self) -> Optional[int]:
        """
        The length of the key in bytes, expressed as an integer. Supported values include the following:
        * AES: 16, 24, or 32
        * RSA: 256, 384, or 512
        * ECDSA: 32, 48, or 66
        """
        return pulumi.get(self, "length")

    @property
    @pulumi.getter(name="managementEndpoint")
    def management_endpoint(self) -> str:
        return pulumi.get(self, "management_endpoint")

    @property
    @pulumi.getter(name="protectionMode")
    def protection_mode(self) -> Optional[str]:
        """
        The key's protection mode indicates how the key persists and where cryptographic operations that use the key are performed. A protection mode of `HSM` means that the key persists on a hardware security module (HSM) and all cryptographic operations are performed inside the HSM. A protection mode of `SOFTWARE` means that the key persists on the server, protected by the vault's RSA wrapping key which persists  on the HSM. All cryptographic operations that use a key with a protection mode of `SOFTWARE` are performed on the server. By default,  a key's protection mode is set to `HSM`. You can't change a key's protection mode after the key is created or imported.
        """
        return pulumi.get(self, "protection_mode")


class AwaitableGetKeysResult(GetKeysResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKeysResult(
            algorithm=self.algorithm,
            compartment_id=self.compartment_id,
            curve_id=self.curve_id,
            filters=self.filters,
            id=self.id,
            keys=self.keys,
            length=self.length,
            management_endpoint=self.management_endpoint,
            protection_mode=self.protection_mode)


def get_keys(algorithm: Optional[str] = None,
             compartment_id: Optional[str] = None,
             curve_id: Optional[str] = None,
             filters: Optional[Sequence[pulumi.InputType['GetKeysFilterArgs']]] = None,
             length: Optional[int] = None,
             management_endpoint: Optional[str] = None,
             protection_mode: Optional[str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetKeysResult:
    """
    This data source provides the list of Keys in Oracle Cloud Infrastructure Kms service.

    Lists the master encryption keys in the specified vault and compartment.

    As a management operation, this call is subject to a Key Management limit that applies to the total number
    of requests across all management read operations. Key Management might throttle this call to reject an
    otherwise valid request when the total rate of management read operations exceeds 10 requests per second
    for a given tenancy.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_keys = oci.Kms.get_keys(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        management_endpoint=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        algorithm=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        length=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        curve_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        protection_mode=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str algorithm: The algorithm used by a key's key versions to encrypt or decrypt data. Currently, support includes AES, RSA, and ECDSA algorithms.
    :param str compartment_id: The OCID of the compartment.
    :param str curve_id: The curve ID of the keys. (This pertains only to ECDSA keys.)
    :param int length: The length of the key in bytes, expressed as an integer. Supported values include 16, 24, or 32.
    :param str management_endpoint: The service endpoint to perform management operations against. Management operations include 'Create,' 'Update,' 'List,' 'Get,' and 'Delete' operations. See Vault Management endpoint.
    :param str protection_mode: A key's protection mode indicates how the key persists and where cryptographic operations that use the key are performed. A  protection mode of `HSM` means that the key persists on a hardware security module (HSM) and all cryptographic operations are  performed inside the HSM. A protection mode of `SOFTWARE` means that the key persists on the server, protected by the vault's  RSA wrapping key which persists on the HSM. All cryptographic operations that use a key with a protection mode of  `SOFTWARE` are performed on the server.
    """
    __args__ = dict()
    __args__['algorithm'] = algorithm
    __args__['compartmentId'] = compartment_id
    __args__['curveId'] = curve_id
    __args__['filters'] = filters
    __args__['length'] = length
    __args__['managementEndpoint'] = management_endpoint
    __args__['protectionMode'] = protection_mode
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Kms/getKeys:getKeys', __args__, opts=opts, typ=GetKeysResult).value

    return AwaitableGetKeysResult(
        algorithm=__ret__.algorithm,
        compartment_id=__ret__.compartment_id,
        curve_id=__ret__.curve_id,
        filters=__ret__.filters,
        id=__ret__.id,
        keys=__ret__.keys,
        length=__ret__.length,
        management_endpoint=__ret__.management_endpoint,
        protection_mode=__ret__.protection_mode)


@_utilities.lift_output_func(get_keys)
def get_keys_output(algorithm: Optional[pulumi.Input[Optional[str]]] = None,
                    compartment_id: Optional[pulumi.Input[str]] = None,
                    curve_id: Optional[pulumi.Input[Optional[str]]] = None,
                    filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetKeysFilterArgs']]]]] = None,
                    length: Optional[pulumi.Input[Optional[int]]] = None,
                    management_endpoint: Optional[pulumi.Input[str]] = None,
                    protection_mode: Optional[pulumi.Input[Optional[str]]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetKeysResult]:
    """
    This data source provides the list of Keys in Oracle Cloud Infrastructure Kms service.

    Lists the master encryption keys in the specified vault and compartment.

    As a management operation, this call is subject to a Key Management limit that applies to the total number
    of requests across all management read operations. Key Management might throttle this call to reject an
    otherwise valid request when the total rate of management read operations exceeds 10 requests per second
    for a given tenancy.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_keys = oci.Kms.get_keys(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        management_endpoint=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        algorithm=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        length=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        curve_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        protection_mode=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str algorithm: The algorithm used by a key's key versions to encrypt or decrypt data. Currently, support includes AES, RSA, and ECDSA algorithms.
    :param str compartment_id: The OCID of the compartment.
    :param str curve_id: The curve ID of the keys. (This pertains only to ECDSA keys.)
    :param int length: The length of the key in bytes, expressed as an integer. Supported values include 16, 24, or 32.
    :param str management_endpoint: The service endpoint to perform management operations against. Management operations include 'Create,' 'Update,' 'List,' 'Get,' and 'Delete' operations. See Vault Management endpoint.
    :param str protection_mode: A key's protection mode indicates how the key persists and where cryptographic operations that use the key are performed. A  protection mode of `HSM` means that the key persists on a hardware security module (HSM) and all cryptographic operations are  performed inside the HSM. A protection mode of `SOFTWARE` means that the key persists on the server, protected by the vault's  RSA wrapping key which persists on the HSM. All cryptographic operations that use a key with a protection mode of  `SOFTWARE` are performed on the server.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['AutonomousContainerDatabaseDataguardRoleChangeArgs', 'AutonomousContainerDatabaseDataguardRoleChange']

@pulumi.input_type
class AutonomousContainerDatabaseDataguardRoleChangeArgs:
    def __init__(__self__, *,
                 autonomous_container_database_dataguard_association_id: pulumi.Input[str],
                 autonomous_container_database_id: pulumi.Input[str],
                 role: pulumi.Input[str],
                 connection_strings_type: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a AutonomousContainerDatabaseDataguardRoleChange resource.
        """
        pulumi.set(__self__, "autonomous_container_database_dataguard_association_id", autonomous_container_database_dataguard_association_id)
        pulumi.set(__self__, "autonomous_container_database_id", autonomous_container_database_id)
        pulumi.set(__self__, "role", role)
        if connection_strings_type is not None:
            pulumi.set(__self__, "connection_strings_type", connection_strings_type)

    @property
    @pulumi.getter(name="autonomousContainerDatabaseDataguardAssociationId")
    def autonomous_container_database_dataguard_association_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "autonomous_container_database_dataguard_association_id")

    @autonomous_container_database_dataguard_association_id.setter
    def autonomous_container_database_dataguard_association_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "autonomous_container_database_dataguard_association_id", value)

    @property
    @pulumi.getter(name="autonomousContainerDatabaseId")
    def autonomous_container_database_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "autonomous_container_database_id")

    @autonomous_container_database_id.setter
    def autonomous_container_database_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "autonomous_container_database_id", value)

    @property
    @pulumi.getter
    def role(self) -> pulumi.Input[str]:
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: pulumi.Input[str]):
        pulumi.set(self, "role", value)

    @property
    @pulumi.getter(name="connectionStringsType")
    def connection_strings_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "connection_strings_type")

    @connection_strings_type.setter
    def connection_strings_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connection_strings_type", value)


@pulumi.input_type
class _AutonomousContainerDatabaseDataguardRoleChangeState:
    def __init__(__self__, *,
                 autonomous_container_database_dataguard_association_id: Optional[pulumi.Input[str]] = None,
                 autonomous_container_database_id: Optional[pulumi.Input[str]] = None,
                 connection_strings_type: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AutonomousContainerDatabaseDataguardRoleChange resources.
        """
        if autonomous_container_database_dataguard_association_id is not None:
            pulumi.set(__self__, "autonomous_container_database_dataguard_association_id", autonomous_container_database_dataguard_association_id)
        if autonomous_container_database_id is not None:
            pulumi.set(__self__, "autonomous_container_database_id", autonomous_container_database_id)
        if connection_strings_type is not None:
            pulumi.set(__self__, "connection_strings_type", connection_strings_type)
        if role is not None:
            pulumi.set(__self__, "role", role)

    @property
    @pulumi.getter(name="autonomousContainerDatabaseDataguardAssociationId")
    def autonomous_container_database_dataguard_association_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "autonomous_container_database_dataguard_association_id")

    @autonomous_container_database_dataguard_association_id.setter
    def autonomous_container_database_dataguard_association_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "autonomous_container_database_dataguard_association_id", value)

    @property
    @pulumi.getter(name="autonomousContainerDatabaseId")
    def autonomous_container_database_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "autonomous_container_database_id")

    @autonomous_container_database_id.setter
    def autonomous_container_database_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "autonomous_container_database_id", value)

    @property
    @pulumi.getter(name="connectionStringsType")
    def connection_strings_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "connection_strings_type")

    @connection_strings_type.setter
    def connection_strings_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connection_strings_type", value)

    @property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role", value)


class AutonomousContainerDatabaseDataguardRoleChange(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 autonomous_container_database_dataguard_association_id: Optional[pulumi.Input[str]] = None,
                 autonomous_container_database_id: Optional[pulumi.Input[str]] = None,
                 connection_strings_type: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Create a AutonomousContainerDatabaseDataguardRoleChange resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AutonomousContainerDatabaseDataguardRoleChangeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a AutonomousContainerDatabaseDataguardRoleChange resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param AutonomousContainerDatabaseDataguardRoleChangeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AutonomousContainerDatabaseDataguardRoleChangeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 autonomous_container_database_dataguard_association_id: Optional[pulumi.Input[str]] = None,
                 autonomous_container_database_id: Optional[pulumi.Input[str]] = None,
                 connection_strings_type: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AutonomousContainerDatabaseDataguardRoleChangeArgs.__new__(AutonomousContainerDatabaseDataguardRoleChangeArgs)

            if autonomous_container_database_dataguard_association_id is None and not opts.urn:
                raise TypeError("Missing required property 'autonomous_container_database_dataguard_association_id'")
            __props__.__dict__["autonomous_container_database_dataguard_association_id"] = autonomous_container_database_dataguard_association_id
            if autonomous_container_database_id is None and not opts.urn:
                raise TypeError("Missing required property 'autonomous_container_database_id'")
            __props__.__dict__["autonomous_container_database_id"] = autonomous_container_database_id
            __props__.__dict__["connection_strings_type"] = connection_strings_type
            if role is None and not opts.urn:
                raise TypeError("Missing required property 'role'")
            __props__.__dict__["role"] = role
        super(AutonomousContainerDatabaseDataguardRoleChange, __self__).__init__(
            'oci:Database/autonomousContainerDatabaseDataguardRoleChange:AutonomousContainerDatabaseDataguardRoleChange',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            autonomous_container_database_dataguard_association_id: Optional[pulumi.Input[str]] = None,
            autonomous_container_database_id: Optional[pulumi.Input[str]] = None,
            connection_strings_type: Optional[pulumi.Input[str]] = None,
            role: Optional[pulumi.Input[str]] = None) -> 'AutonomousContainerDatabaseDataguardRoleChange':
        """
        Get an existing AutonomousContainerDatabaseDataguardRoleChange resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AutonomousContainerDatabaseDataguardRoleChangeState.__new__(_AutonomousContainerDatabaseDataguardRoleChangeState)

        __props__.__dict__["autonomous_container_database_dataguard_association_id"] = autonomous_container_database_dataguard_association_id
        __props__.__dict__["autonomous_container_database_id"] = autonomous_container_database_id
        __props__.__dict__["connection_strings_type"] = connection_strings_type
        __props__.__dict__["role"] = role
        return AutonomousContainerDatabaseDataguardRoleChange(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autonomousContainerDatabaseDataguardAssociationId")
    def autonomous_container_database_dataguard_association_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "autonomous_container_database_dataguard_association_id")

    @property
    @pulumi.getter(name="autonomousContainerDatabaseId")
    def autonomous_container_database_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "autonomous_container_database_id")

    @property
    @pulumi.getter(name="connectionStringsType")
    def connection_strings_type(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "connection_strings_type")

    @property
    @pulumi.getter
    def role(self) -> pulumi.Output[str]:
        return pulumi.get(self, "role")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DomainArgs', 'Domain']

@pulumi.input_type
class DomainArgs:
    def __init__(__self__, *,
                 compartment_id: pulumi.Input[str],
                 description: pulumi.Input[str],
                 display_name: pulumi.Input[str],
                 home_region: pulumi.Input[str],
                 license_type: pulumi.Input[str],
                 admin_email: Optional[pulumi.Input[str]] = None,
                 admin_first_name: Optional[pulumi.Input[str]] = None,
                 admin_last_name: Optional[pulumi.Input[str]] = None,
                 admin_user_name: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 is_hidden_on_login: Optional[pulumi.Input[bool]] = None,
                 is_notification_bypassed: Optional[pulumi.Input[bool]] = None,
                 is_primary_email_required: Optional[pulumi.Input[bool]] = None,
                 state: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Domain resource.
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the Compartment where domain is created
        :param pulumi.Input[str] description: (Updatable) Domain entity description
        :param pulumi.Input[str] display_name: (Updatable) The mutable display name of the domain.
        :param pulumi.Input[str] home_region: The region's name. See [Regions and Availability Domains](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/regions.htm) for the full list of supported region names.  Example: `us-phoenix-1`
        :param pulumi.Input[str] license_type: The License type of Domain
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] admin_email: The admin email address
        :param pulumi.Input[str] admin_first_name: The admin first name
        :param pulumi.Input[str] admin_last_name: The admin last name
        :param pulumi.Input[str] admin_user_name: The admin user name
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[bool] is_hidden_on_login: (Updatable) Indicates whether domain is hidden on login screen or not.
        :param pulumi.Input[bool] is_notification_bypassed: Indicates if admin user created in IDCS stripe would like to receive notification like welcome email or not. Required field only if admin information is provided, otherwise optional.
        :param pulumi.Input[bool] is_primary_email_required: Optional field to indicate whether users in the domain are required to have a primary email address or not Defaults to true
        :param pulumi.Input[str] state: The current state.
        """
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "home_region", home_region)
        pulumi.set(__self__, "license_type", license_type)
        if admin_email is not None:
            pulumi.set(__self__, "admin_email", admin_email)
        if admin_first_name is not None:
            pulumi.set(__self__, "admin_first_name", admin_first_name)
        if admin_last_name is not None:
            pulumi.set(__self__, "admin_last_name", admin_last_name)
        if admin_user_name is not None:
            pulumi.set(__self__, "admin_user_name", admin_user_name)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if is_hidden_on_login is not None:
            pulumi.set(__self__, "is_hidden_on_login", is_hidden_on_login)
        if is_notification_bypassed is not None:
            pulumi.set(__self__, "is_notification_bypassed", is_notification_bypassed)
        if is_primary_email_required is not None:
            pulumi.set(__self__, "is_primary_email_required", is_primary_email_required)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        (Updatable) The OCID of the Compartment where domain is created
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Input[str]:
        """
        (Updatable) Domain entity description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[str]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[str]:
        """
        (Updatable) The mutable display name of the domain.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="homeRegion")
    def home_region(self) -> pulumi.Input[str]:
        """
        The region's name. See [Regions and Availability Domains](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/regions.htm) for the full list of supported region names.  Example: `us-phoenix-1`
        """
        return pulumi.get(self, "home_region")

    @home_region.setter
    def home_region(self, value: pulumi.Input[str]):
        pulumi.set(self, "home_region", value)

    @property
    @pulumi.getter(name="licenseType")
    def license_type(self) -> pulumi.Input[str]:
        """
        The License type of Domain


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "license_type")

    @license_type.setter
    def license_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "license_type", value)

    @property
    @pulumi.getter(name="adminEmail")
    def admin_email(self) -> Optional[pulumi.Input[str]]:
        """
        The admin email address
        """
        return pulumi.get(self, "admin_email")

    @admin_email.setter
    def admin_email(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "admin_email", value)

    @property
    @pulumi.getter(name="adminFirstName")
    def admin_first_name(self) -> Optional[pulumi.Input[str]]:
        """
        The admin first name
        """
        return pulumi.get(self, "admin_first_name")

    @admin_first_name.setter
    def admin_first_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "admin_first_name", value)

    @property
    @pulumi.getter(name="adminLastName")
    def admin_last_name(self) -> Optional[pulumi.Input[str]]:
        """
        The admin last name
        """
        return pulumi.get(self, "admin_last_name")

    @admin_last_name.setter
    def admin_last_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "admin_last_name", value)

    @property
    @pulumi.getter(name="adminUserName")
    def admin_user_name(self) -> Optional[pulumi.Input[str]]:
        """
        The admin user name
        """
        return pulumi.get(self, "admin_user_name")

    @admin_user_name.setter
    def admin_user_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "admin_user_name", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="isHiddenOnLogin")
    def is_hidden_on_login(self) -> Optional[pulumi.Input[bool]]:
        """
        (Updatable) Indicates whether domain is hidden on login screen or not.
        """
        return pulumi.get(self, "is_hidden_on_login")

    @is_hidden_on_login.setter
    def is_hidden_on_login(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_hidden_on_login", value)

    @property
    @pulumi.getter(name="isNotificationBypassed")
    def is_notification_bypassed(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates if admin user created in IDCS stripe would like to receive notification like welcome email or not. Required field only if admin information is provided, otherwise optional.
        """
        return pulumi.get(self, "is_notification_bypassed")

    @is_notification_bypassed.setter
    def is_notification_bypassed(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_notification_bypassed", value)

    @property
    @pulumi.getter(name="isPrimaryEmailRequired")
    def is_primary_email_required(self) -> Optional[pulumi.Input[bool]]:
        """
        Optional field to indicate whether users in the domain are required to have a primary email address or not Defaults to true
        """
        return pulumi.get(self, "is_primary_email_required")

    @is_primary_email_required.setter
    def is_primary_email_required(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_primary_email_required", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current state.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)


@pulumi.input_type
class _DomainState:
    def __init__(__self__, *,
                 admin_email: Optional[pulumi.Input[str]] = None,
                 admin_first_name: Optional[pulumi.Input[str]] = None,
                 admin_last_name: Optional[pulumi.Input[str]] = None,
                 admin_user_name: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 home_region: Optional[pulumi.Input[str]] = None,
                 home_region_url: Optional[pulumi.Input[str]] = None,
                 is_hidden_on_login: Optional[pulumi.Input[bool]] = None,
                 is_notification_bypassed: Optional[pulumi.Input[bool]] = None,
                 is_primary_email_required: Optional[pulumi.Input[bool]] = None,
                 license_type: Optional[pulumi.Input[str]] = None,
                 lifecycle_details: Optional[pulumi.Input[str]] = None,
                 replica_regions: Optional[pulumi.Input[Sequence[pulumi.Input['DomainReplicaRegionArgs']]]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 time_created: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 url: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Domain resources.
        :param pulumi.Input[str] admin_email: The admin email address
        :param pulumi.Input[str] admin_first_name: The admin first name
        :param pulumi.Input[str] admin_last_name: The admin last name
        :param pulumi.Input[str] admin_user_name: The admin user name
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the Compartment where domain is created
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] description: (Updatable) Domain entity description
        :param pulumi.Input[str] display_name: (Updatable) The mutable display name of the domain.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] home_region: The region's name. See [Regions and Availability Domains](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/regions.htm) for the full list of supported region names.  Example: `us-phoenix-1`
        :param pulumi.Input[str] home_region_url: Region specific domain URL.
        :param pulumi.Input[bool] is_hidden_on_login: (Updatable) Indicates whether domain is hidden on login screen or not.
        :param pulumi.Input[bool] is_notification_bypassed: Indicates if admin user created in IDCS stripe would like to receive notification like welcome email or not. Required field only if admin information is provided, otherwise optional.
        :param pulumi.Input[bool] is_primary_email_required: Optional field to indicate whether users in the domain are required to have a primary email address or not Defaults to true
        :param pulumi.Input[str] license_type: The License type of Domain
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] lifecycle_details: Any additional details about the current state of the Domain.
        :param pulumi.Input[Sequence[pulumi.Input['DomainReplicaRegionArgs']]] replica_regions: The regions domain is replication to.
        :param pulumi.Input[str] state: The current state.
        :param pulumi.Input[str] time_created: Date and time the domain was created, in the format defined by RFC3339.  Example: `2016-08-25T21:10:29.600Z`
        :param pulumi.Input[str] type: The type of the domain.
        :param pulumi.Input[str] url: Region agnostic domain URL.
        """
        if admin_email is not None:
            pulumi.set(__self__, "admin_email", admin_email)
        if admin_first_name is not None:
            pulumi.set(__self__, "admin_first_name", admin_first_name)
        if admin_last_name is not None:
            pulumi.set(__self__, "admin_last_name", admin_last_name)
        if admin_user_name is not None:
            pulumi.set(__self__, "admin_user_name", admin_user_name)
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if home_region is not None:
            pulumi.set(__self__, "home_region", home_region)
        if home_region_url is not None:
            pulumi.set(__self__, "home_region_url", home_region_url)
        if is_hidden_on_login is not None:
            pulumi.set(__self__, "is_hidden_on_login", is_hidden_on_login)
        if is_notification_bypassed is not None:
            pulumi.set(__self__, "is_notification_bypassed", is_notification_bypassed)
        if is_primary_email_required is not None:
            pulumi.set(__self__, "is_primary_email_required", is_primary_email_required)
        if license_type is not None:
            pulumi.set(__self__, "license_type", license_type)
        if lifecycle_details is not None:
            pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if replica_regions is not None:
            pulumi.set(__self__, "replica_regions", replica_regions)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter(name="adminEmail")
    def admin_email(self) -> Optional[pulumi.Input[str]]:
        """
        The admin email address
        """
        return pulumi.get(self, "admin_email")

    @admin_email.setter
    def admin_email(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "admin_email", value)

    @property
    @pulumi.getter(name="adminFirstName")
    def admin_first_name(self) -> Optional[pulumi.Input[str]]:
        """
        The admin first name
        """
        return pulumi.get(self, "admin_first_name")

    @admin_first_name.setter
    def admin_first_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "admin_first_name", value)

    @property
    @pulumi.getter(name="adminLastName")
    def admin_last_name(self) -> Optional[pulumi.Input[str]]:
        """
        The admin last name
        """
        return pulumi.get(self, "admin_last_name")

    @admin_last_name.setter
    def admin_last_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "admin_last_name", value)

    @property
    @pulumi.getter(name="adminUserName")
    def admin_user_name(self) -> Optional[pulumi.Input[str]]:
        """
        The admin user name
        """
        return pulumi.get(self, "admin_user_name")

    @admin_user_name.setter
    def admin_user_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "admin_user_name", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The OCID of the Compartment where domain is created
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Domain entity description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The mutable display name of the domain.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="homeRegion")
    def home_region(self) -> Optional[pulumi.Input[str]]:
        """
        The region's name. See [Regions and Availability Domains](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/regions.htm) for the full list of supported region names.  Example: `us-phoenix-1`
        """
        return pulumi.get(self, "home_region")

    @home_region.setter
    def home_region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "home_region", value)

    @property
    @pulumi.getter(name="homeRegionUrl")
    def home_region_url(self) -> Optional[pulumi.Input[str]]:
        """
        Region specific domain URL.
        """
        return pulumi.get(self, "home_region_url")

    @home_region_url.setter
    def home_region_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "home_region_url", value)

    @property
    @pulumi.getter(name="isHiddenOnLogin")
    def is_hidden_on_login(self) -> Optional[pulumi.Input[bool]]:
        """
        (Updatable) Indicates whether domain is hidden on login screen or not.
        """
        return pulumi.get(self, "is_hidden_on_login")

    @is_hidden_on_login.setter
    def is_hidden_on_login(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_hidden_on_login", value)

    @property
    @pulumi.getter(name="isNotificationBypassed")
    def is_notification_bypassed(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates if admin user created in IDCS stripe would like to receive notification like welcome email or not. Required field only if admin information is provided, otherwise optional.
        """
        return pulumi.get(self, "is_notification_bypassed")

    @is_notification_bypassed.setter
    def is_notification_bypassed(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_notification_bypassed", value)

    @property
    @pulumi.getter(name="isPrimaryEmailRequired")
    def is_primary_email_required(self) -> Optional[pulumi.Input[bool]]:
        """
        Optional field to indicate whether users in the domain are required to have a primary email address or not Defaults to true
        """
        return pulumi.get(self, "is_primary_email_required")

    @is_primary_email_required.setter
    def is_primary_email_required(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_primary_email_required", value)

    @property
    @pulumi.getter(name="licenseType")
    def license_type(self) -> Optional[pulumi.Input[str]]:
        """
        The License type of Domain


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "license_type")

    @license_type.setter
    def license_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "license_type", value)

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> Optional[pulumi.Input[str]]:
        """
        Any additional details about the current state of the Domain.
        """
        return pulumi.get(self, "lifecycle_details")

    @lifecycle_details.setter
    def lifecycle_details(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lifecycle_details", value)

    @property
    @pulumi.getter(name="replicaRegions")
    def replica_regions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DomainReplicaRegionArgs']]]]:
        """
        The regions domain is replication to.
        """
        return pulumi.get(self, "replica_regions")

    @replica_regions.setter
    def replica_regions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DomainReplicaRegionArgs']]]]):
        pulumi.set(self, "replica_regions", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current state.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        Date and time the domain was created, in the format defined by RFC3339.  Example: `2016-08-25T21:10:29.600Z`
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the domain.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[str]]:
        """
        Region agnostic domain URL.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "url", value)


class Domain(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 admin_email: Optional[pulumi.Input[str]] = None,
                 admin_first_name: Optional[pulumi.Input[str]] = None,
                 admin_last_name: Optional[pulumi.Input[str]] = None,
                 admin_user_name: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 home_region: Optional[pulumi.Input[str]] = None,
                 is_hidden_on_login: Optional[pulumi.Input[bool]] = None,
                 is_notification_bypassed: Optional[pulumi.Input[bool]] = None,
                 is_primary_email_required: Optional[pulumi.Input[bool]] = None,
                 license_type: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Domain resource in Oracle Cloud Infrastructure Identity service.

        Creates a new domain in the tenancy with domain home in {@code homeRegion}. This is an asynchronous call - where, at start,
        {@code lifecycleState} of this domain is set to CREATING and {@code lifecycleDetails} to UPDATING. On domain creation completion
        this Domain's {@code lifecycleState} will be set to ACTIVE and {@code lifecycleDetails} to null.

        To track progress, HTTP GET on /iamWorkRequests/{iamWorkRequestsId} endpoint will provide
        the async operation's status.

        After creating a `Domain`, make sure its `lifecycleState` changes from CREATING to ACTIVE
        before using it.
        If the domain's {@code displayName} already exists, returns 400 BAD REQUEST.
        If any one of admin related fields are provided and one of the following 3 fields
        - {@code adminEmail}, {@code adminLastName} and {@code adminUserName} - is not provided,
          returns 400 BAD REQUEST.
        - If {@code isNotificationBypassed} is NOT provided when admin information is provided,
          returns 400 BAD REQUEST.
        - If any internal error occurs, return 500 INTERNAL SERVER ERROR.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_domain = oci.identity.Domain("testDomain",
            compartment_id=var["compartment_id"],
            description=var["domain_description"],
            display_name=var["domain_display_name"],
            home_region=var["domain_home_region"],
            license_type=var["domain_license_type"],
            admin_email=var["domain_admin_email"],
            admin_first_name=var["domain_admin_first_name"],
            admin_last_name=var["domain_admin_last_name"],
            admin_user_name=oci_identity_user["test_user"]["name"],
            defined_tags={
                "Operations.CostCenter": "42",
            },
            freeform_tags={
                "Department": "Finance",
            },
            is_hidden_on_login=var["domain_is_hidden_on_login"],
            is_notification_bypassed=var["domain_is_notification_bypassed"],
            is_primary_email_required=var["domain_is_primary_email_required"])
        ```

        ## Import

        Domains can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Identity/domain:Domain test_domain "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] admin_email: The admin email address
        :param pulumi.Input[str] admin_first_name: The admin first name
        :param pulumi.Input[str] admin_last_name: The admin last name
        :param pulumi.Input[str] admin_user_name: The admin user name
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the Compartment where domain is created
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] description: (Updatable) Domain entity description
        :param pulumi.Input[str] display_name: (Updatable) The mutable display name of the domain.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] home_region: The region's name. See [Regions and Availability Domains](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/regions.htm) for the full list of supported region names.  Example: `us-phoenix-1`
        :param pulumi.Input[bool] is_hidden_on_login: (Updatable) Indicates whether domain is hidden on login screen or not.
        :param pulumi.Input[bool] is_notification_bypassed: Indicates if admin user created in IDCS stripe would like to receive notification like welcome email or not. Required field only if admin information is provided, otherwise optional.
        :param pulumi.Input[bool] is_primary_email_required: Optional field to indicate whether users in the domain are required to have a primary email address or not Defaults to true
        :param pulumi.Input[str] license_type: The License type of Domain
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] state: The current state.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DomainArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Domain resource in Oracle Cloud Infrastructure Identity service.

        Creates a new domain in the tenancy with domain home in {@code homeRegion}. This is an asynchronous call - where, at start,
        {@code lifecycleState} of this domain is set to CREATING and {@code lifecycleDetails} to UPDATING. On domain creation completion
        this Domain's {@code lifecycleState} will be set to ACTIVE and {@code lifecycleDetails} to null.

        To track progress, HTTP GET on /iamWorkRequests/{iamWorkRequestsId} endpoint will provide
        the async operation's status.

        After creating a `Domain`, make sure its `lifecycleState` changes from CREATING to ACTIVE
        before using it.
        If the domain's {@code displayName} already exists, returns 400 BAD REQUEST.
        If any one of admin related fields are provided and one of the following 3 fields
        - {@code adminEmail}, {@code adminLastName} and {@code adminUserName} - is not provided,
          returns 400 BAD REQUEST.
        - If {@code isNotificationBypassed} is NOT provided when admin information is provided,
          returns 400 BAD REQUEST.
        - If any internal error occurs, return 500 INTERNAL SERVER ERROR.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_domain = oci.identity.Domain("testDomain",
            compartment_id=var["compartment_id"],
            description=var["domain_description"],
            display_name=var["domain_display_name"],
            home_region=var["domain_home_region"],
            license_type=var["domain_license_type"],
            admin_email=var["domain_admin_email"],
            admin_first_name=var["domain_admin_first_name"],
            admin_last_name=var["domain_admin_last_name"],
            admin_user_name=oci_identity_user["test_user"]["name"],
            defined_tags={
                "Operations.CostCenter": "42",
            },
            freeform_tags={
                "Department": "Finance",
            },
            is_hidden_on_login=var["domain_is_hidden_on_login"],
            is_notification_bypassed=var["domain_is_notification_bypassed"],
            is_primary_email_required=var["domain_is_primary_email_required"])
        ```

        ## Import

        Domains can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Identity/domain:Domain test_domain "id"
        ```

        :param str resource_name: The name of the resource.
        :param DomainArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DomainArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 admin_email: Optional[pulumi.Input[str]] = None,
                 admin_first_name: Optional[pulumi.Input[str]] = None,
                 admin_last_name: Optional[pulumi.Input[str]] = None,
                 admin_user_name: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 home_region: Optional[pulumi.Input[str]] = None,
                 is_hidden_on_login: Optional[pulumi.Input[bool]] = None,
                 is_notification_bypassed: Optional[pulumi.Input[bool]] = None,
                 is_primary_email_required: Optional[pulumi.Input[bool]] = None,
                 license_type: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DomainArgs.__new__(DomainArgs)

            __props__.__dict__["admin_email"] = admin_email
            __props__.__dict__["admin_first_name"] = admin_first_name
            __props__.__dict__["admin_last_name"] = admin_last_name
            __props__.__dict__["admin_user_name"] = admin_user_name
            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["defined_tags"] = defined_tags
            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["freeform_tags"] = freeform_tags
            if home_region is None and not opts.urn:
                raise TypeError("Missing required property 'home_region'")
            __props__.__dict__["home_region"] = home_region
            __props__.__dict__["is_hidden_on_login"] = is_hidden_on_login
            __props__.__dict__["is_notification_bypassed"] = is_notification_bypassed
            __props__.__dict__["is_primary_email_required"] = is_primary_email_required
            if license_type is None and not opts.urn:
                raise TypeError("Missing required property 'license_type'")
            __props__.__dict__["license_type"] = license_type
            __props__.__dict__["state"] = state
            __props__.__dict__["home_region_url"] = None
            __props__.__dict__["lifecycle_details"] = None
            __props__.__dict__["replica_regions"] = None
            __props__.__dict__["time_created"] = None
            __props__.__dict__["type"] = None
            __props__.__dict__["url"] = None
        super(Domain, __self__).__init__(
            'oci:Identity/domain:Domain',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            admin_email: Optional[pulumi.Input[str]] = None,
            admin_first_name: Optional[pulumi.Input[str]] = None,
            admin_last_name: Optional[pulumi.Input[str]] = None,
            admin_user_name: Optional[pulumi.Input[str]] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            description: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            home_region: Optional[pulumi.Input[str]] = None,
            home_region_url: Optional[pulumi.Input[str]] = None,
            is_hidden_on_login: Optional[pulumi.Input[bool]] = None,
            is_notification_bypassed: Optional[pulumi.Input[bool]] = None,
            is_primary_email_required: Optional[pulumi.Input[bool]] = None,
            license_type: Optional[pulumi.Input[str]] = None,
            lifecycle_details: Optional[pulumi.Input[str]] = None,
            replica_regions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DomainReplicaRegionArgs']]]]] = None,
            state: Optional[pulumi.Input[str]] = None,
            time_created: Optional[pulumi.Input[str]] = None,
            type: Optional[pulumi.Input[str]] = None,
            url: Optional[pulumi.Input[str]] = None) -> 'Domain':
        """
        Get an existing Domain resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] admin_email: The admin email address
        :param pulumi.Input[str] admin_first_name: The admin first name
        :param pulumi.Input[str] admin_last_name: The admin last name
        :param pulumi.Input[str] admin_user_name: The admin user name
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the Compartment where domain is created
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] description: (Updatable) Domain entity description
        :param pulumi.Input[str] display_name: (Updatable) The mutable display name of the domain.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] home_region: The region's name. See [Regions and Availability Domains](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/regions.htm) for the full list of supported region names.  Example: `us-phoenix-1`
        :param pulumi.Input[str] home_region_url: Region specific domain URL.
        :param pulumi.Input[bool] is_hidden_on_login: (Updatable) Indicates whether domain is hidden on login screen or not.
        :param pulumi.Input[bool] is_notification_bypassed: Indicates if admin user created in IDCS stripe would like to receive notification like welcome email or not. Required field only if admin information is provided, otherwise optional.
        :param pulumi.Input[bool] is_primary_email_required: Optional field to indicate whether users in the domain are required to have a primary email address or not Defaults to true
        :param pulumi.Input[str] license_type: The License type of Domain
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] lifecycle_details: Any additional details about the current state of the Domain.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DomainReplicaRegionArgs']]]] replica_regions: The regions domain is replication to.
        :param pulumi.Input[str] state: The current state.
        :param pulumi.Input[str] time_created: Date and time the domain was created, in the format defined by RFC3339.  Example: `2016-08-25T21:10:29.600Z`
        :param pulumi.Input[str] type: The type of the domain.
        :param pulumi.Input[str] url: Region agnostic domain URL.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DomainState.__new__(_DomainState)

        __props__.__dict__["admin_email"] = admin_email
        __props__.__dict__["admin_first_name"] = admin_first_name
        __props__.__dict__["admin_last_name"] = admin_last_name
        __props__.__dict__["admin_user_name"] = admin_user_name
        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["defined_tags"] = defined_tags
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["freeform_tags"] = freeform_tags
        __props__.__dict__["home_region"] = home_region
        __props__.__dict__["home_region_url"] = home_region_url
        __props__.__dict__["is_hidden_on_login"] = is_hidden_on_login
        __props__.__dict__["is_notification_bypassed"] = is_notification_bypassed
        __props__.__dict__["is_primary_email_required"] = is_primary_email_required
        __props__.__dict__["license_type"] = license_type
        __props__.__dict__["lifecycle_details"] = lifecycle_details
        __props__.__dict__["replica_regions"] = replica_regions
        __props__.__dict__["state"] = state
        __props__.__dict__["time_created"] = time_created
        __props__.__dict__["type"] = type
        __props__.__dict__["url"] = url
        return Domain(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="adminEmail")
    def admin_email(self) -> pulumi.Output[str]:
        """
        The admin email address
        """
        return pulumi.get(self, "admin_email")

    @property
    @pulumi.getter(name="adminFirstName")
    def admin_first_name(self) -> pulumi.Output[str]:
        """
        The admin first name
        """
        return pulumi.get(self, "admin_first_name")

    @property
    @pulumi.getter(name="adminLastName")
    def admin_last_name(self) -> pulumi.Output[str]:
        """
        The admin last name
        """
        return pulumi.get(self, "admin_last_name")

    @property
    @pulumi.getter(name="adminUserName")
    def admin_user_name(self) -> pulumi.Output[str]:
        """
        The admin user name
        """
        return pulumi.get(self, "admin_user_name")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        (Updatable) The OCID of the Compartment where domain is created
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        (Updatable) Domain entity description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        (Updatable) The mutable display name of the domain.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter(name="homeRegion")
    def home_region(self) -> pulumi.Output[str]:
        """
        The region's name. See [Regions and Availability Domains](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/regions.htm) for the full list of supported region names.  Example: `us-phoenix-1`
        """
        return pulumi.get(self, "home_region")

    @property
    @pulumi.getter(name="homeRegionUrl")
    def home_region_url(self) -> pulumi.Output[str]:
        """
        Region specific domain URL.
        """
        return pulumi.get(self, "home_region_url")

    @property
    @pulumi.getter(name="isHiddenOnLogin")
    def is_hidden_on_login(self) -> pulumi.Output[bool]:
        """
        (Updatable) Indicates whether domain is hidden on login screen or not.
        """
        return pulumi.get(self, "is_hidden_on_login")

    @property
    @pulumi.getter(name="isNotificationBypassed")
    def is_notification_bypassed(self) -> pulumi.Output[bool]:
        """
        Indicates if admin user created in IDCS stripe would like to receive notification like welcome email or not. Required field only if admin information is provided, otherwise optional.
        """
        return pulumi.get(self, "is_notification_bypassed")

    @property
    @pulumi.getter(name="isPrimaryEmailRequired")
    def is_primary_email_required(self) -> pulumi.Output[bool]:
        """
        Optional field to indicate whether users in the domain are required to have a primary email address or not Defaults to true
        """
        return pulumi.get(self, "is_primary_email_required")

    @property
    @pulumi.getter(name="licenseType")
    def license_type(self) -> pulumi.Output[str]:
        """
        The License type of Domain


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "license_type")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> pulumi.Output[str]:
        """
        Any additional details about the current state of the Domain.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter(name="replicaRegions")
    def replica_regions(self) -> pulumi.Output[Sequence['outputs.DomainReplicaRegion']]:
        """
        The regions domain is replication to.
        """
        return pulumi.get(self, "replica_regions")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The current state.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        Date and time the domain was created, in the format defined by RFC3339.  Example: `2016-08-25T21:10:29.600Z`
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        The type of the domain.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[str]:
        """
        Region agnostic domain URL.
        """
        return pulumi.get(self, "url")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ModelProvenanceArgs', 'ModelProvenance']

@pulumi.input_type
class ModelProvenanceArgs:
    def __init__(__self__, *,
                 model_id: pulumi.Input[str],
                 git_branch: Optional[pulumi.Input[str]] = None,
                 git_commit: Optional[pulumi.Input[str]] = None,
                 repository_url: Optional[pulumi.Input[str]] = None,
                 script_dir: Optional[pulumi.Input[str]] = None,
                 training_id: Optional[pulumi.Input[str]] = None,
                 training_script: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ModelProvenance resource.
        :param pulumi.Input[str] model_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the model.
        :param pulumi.Input[str] git_branch: (Updatable) For model reproducibility purposes. Branch of the git repository associated with model training.
        :param pulumi.Input[str] git_commit: (Updatable) For model reproducibility purposes. Commit ID of the git repository associated with model training.
        :param pulumi.Input[str] repository_url: (Updatable) For model reproducibility purposes. URL of the git repository associated with model training.
        :param pulumi.Input[str] script_dir: (Updatable) For model reproducibility purposes. Path to model artifacts.
        :param pulumi.Input[str] training_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of a training session(Job or NotebookSession) in which the model was trained. It is used for model reproducibility purposes.
        :param pulumi.Input[str] training_script: (Updatable) For model reproducibility purposes. Path to the python script or notebook in which the model was trained." 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        pulumi.set(__self__, "model_id", model_id)
        if git_branch is not None:
            pulumi.set(__self__, "git_branch", git_branch)
        if git_commit is not None:
            pulumi.set(__self__, "git_commit", git_commit)
        if repository_url is not None:
            pulumi.set(__self__, "repository_url", repository_url)
        if script_dir is not None:
            pulumi.set(__self__, "script_dir", script_dir)
        if training_id is not None:
            pulumi.set(__self__, "training_id", training_id)
        if training_script is not None:
            pulumi.set(__self__, "training_script", training_script)

    @property
    @pulumi.getter(name="modelId")
    def model_id(self) -> pulumi.Input[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the model.
        """
        return pulumi.get(self, "model_id")

    @model_id.setter
    def model_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "model_id", value)

    @property
    @pulumi.getter(name="gitBranch")
    def git_branch(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) For model reproducibility purposes. Branch of the git repository associated with model training.
        """
        return pulumi.get(self, "git_branch")

    @git_branch.setter
    def git_branch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "git_branch", value)

    @property
    @pulumi.getter(name="gitCommit")
    def git_commit(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) For model reproducibility purposes. Commit ID of the git repository associated with model training.
        """
        return pulumi.get(self, "git_commit")

    @git_commit.setter
    def git_commit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "git_commit", value)

    @property
    @pulumi.getter(name="repositoryUrl")
    def repository_url(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) For model reproducibility purposes. URL of the git repository associated with model training.
        """
        return pulumi.get(self, "repository_url")

    @repository_url.setter
    def repository_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "repository_url", value)

    @property
    @pulumi.getter(name="scriptDir")
    def script_dir(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) For model reproducibility purposes. Path to model artifacts.
        """
        return pulumi.get(self, "script_dir")

    @script_dir.setter
    def script_dir(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "script_dir", value)

    @property
    @pulumi.getter(name="trainingId")
    def training_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of a training session(Job or NotebookSession) in which the model was trained. It is used for model reproducibility purposes.
        """
        return pulumi.get(self, "training_id")

    @training_id.setter
    def training_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "training_id", value)

    @property
    @pulumi.getter(name="trainingScript")
    def training_script(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) For model reproducibility purposes. Path to the python script or notebook in which the model was trained." 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "training_script")

    @training_script.setter
    def training_script(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "training_script", value)


@pulumi.input_type
class _ModelProvenanceState:
    def __init__(__self__, *,
                 git_branch: Optional[pulumi.Input[str]] = None,
                 git_commit: Optional[pulumi.Input[str]] = None,
                 model_id: Optional[pulumi.Input[str]] = None,
                 repository_url: Optional[pulumi.Input[str]] = None,
                 script_dir: Optional[pulumi.Input[str]] = None,
                 training_id: Optional[pulumi.Input[str]] = None,
                 training_script: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ModelProvenance resources.
        :param pulumi.Input[str] git_branch: (Updatable) For model reproducibility purposes. Branch of the git repository associated with model training.
        :param pulumi.Input[str] git_commit: (Updatable) For model reproducibility purposes. Commit ID of the git repository associated with model training.
        :param pulumi.Input[str] model_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the model.
        :param pulumi.Input[str] repository_url: (Updatable) For model reproducibility purposes. URL of the git repository associated with model training.
        :param pulumi.Input[str] script_dir: (Updatable) For model reproducibility purposes. Path to model artifacts.
        :param pulumi.Input[str] training_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of a training session(Job or NotebookSession) in which the model was trained. It is used for model reproducibility purposes.
        :param pulumi.Input[str] training_script: (Updatable) For model reproducibility purposes. Path to the python script or notebook in which the model was trained." 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        if git_branch is not None:
            pulumi.set(__self__, "git_branch", git_branch)
        if git_commit is not None:
            pulumi.set(__self__, "git_commit", git_commit)
        if model_id is not None:
            pulumi.set(__self__, "model_id", model_id)
        if repository_url is not None:
            pulumi.set(__self__, "repository_url", repository_url)
        if script_dir is not None:
            pulumi.set(__self__, "script_dir", script_dir)
        if training_id is not None:
            pulumi.set(__self__, "training_id", training_id)
        if training_script is not None:
            pulumi.set(__self__, "training_script", training_script)

    @property
    @pulumi.getter(name="gitBranch")
    def git_branch(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) For model reproducibility purposes. Branch of the git repository associated with model training.
        """
        return pulumi.get(self, "git_branch")

    @git_branch.setter
    def git_branch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "git_branch", value)

    @property
    @pulumi.getter(name="gitCommit")
    def git_commit(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) For model reproducibility purposes. Commit ID of the git repository associated with model training.
        """
        return pulumi.get(self, "git_commit")

    @git_commit.setter
    def git_commit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "git_commit", value)

    @property
    @pulumi.getter(name="modelId")
    def model_id(self) -> Optional[pulumi.Input[str]]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the model.
        """
        return pulumi.get(self, "model_id")

    @model_id.setter
    def model_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "model_id", value)

    @property
    @pulumi.getter(name="repositoryUrl")
    def repository_url(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) For model reproducibility purposes. URL of the git repository associated with model training.
        """
        return pulumi.get(self, "repository_url")

    @repository_url.setter
    def repository_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "repository_url", value)

    @property
    @pulumi.getter(name="scriptDir")
    def script_dir(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) For model reproducibility purposes. Path to model artifacts.
        """
        return pulumi.get(self, "script_dir")

    @script_dir.setter
    def script_dir(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "script_dir", value)

    @property
    @pulumi.getter(name="trainingId")
    def training_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of a training session(Job or NotebookSession) in which the model was trained. It is used for model reproducibility purposes.
        """
        return pulumi.get(self, "training_id")

    @training_id.setter
    def training_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "training_id", value)

    @property
    @pulumi.getter(name="trainingScript")
    def training_script(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) For model reproducibility purposes. Path to the python script or notebook in which the model was trained." 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "training_script")

    @training_script.setter
    def training_script(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "training_script", value)


class ModelProvenance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 git_branch: Optional[pulumi.Input[str]] = None,
                 git_commit: Optional[pulumi.Input[str]] = None,
                 model_id: Optional[pulumi.Input[str]] = None,
                 repository_url: Optional[pulumi.Input[str]] = None,
                 script_dir: Optional[pulumi.Input[str]] = None,
                 training_id: Optional[pulumi.Input[str]] = None,
                 training_script: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Model Provenance resource in Oracle Cloud Infrastructure Data Science service.

        Creates provenance information for the specified model.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_model_provenance = oci.data_science.ModelProvenance("testModelProvenance",
            model_id=oci_datascience_model["test_model"]["id"],
            git_branch=var["model_provenance_git_branch"],
            git_commit=var["model_provenance_git_commit"],
            repository_url=var["model_provenance_repository_url"],
            script_dir=var["model_provenance_script_dir"],
            training_id=oci_datascience_training["test_training"]["id"],
            training_script=var["model_provenance_training_script"])
        ```

        ## Import

        ModelProvenances can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:DataScience/modelProvenance:ModelProvenance test_model_provenance "models/{modelId}/provenance"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] git_branch: (Updatable) For model reproducibility purposes. Branch of the git repository associated with model training.
        :param pulumi.Input[str] git_commit: (Updatable) For model reproducibility purposes. Commit ID of the git repository associated with model training.
        :param pulumi.Input[str] model_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the model.
        :param pulumi.Input[str] repository_url: (Updatable) For model reproducibility purposes. URL of the git repository associated with model training.
        :param pulumi.Input[str] script_dir: (Updatable) For model reproducibility purposes. Path to model artifacts.
        :param pulumi.Input[str] training_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of a training session(Job or NotebookSession) in which the model was trained. It is used for model reproducibility purposes.
        :param pulumi.Input[str] training_script: (Updatable) For model reproducibility purposes. Path to the python script or notebook in which the model was trained." 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ModelProvenanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Model Provenance resource in Oracle Cloud Infrastructure Data Science service.

        Creates provenance information for the specified model.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_model_provenance = oci.data_science.ModelProvenance("testModelProvenance",
            model_id=oci_datascience_model["test_model"]["id"],
            git_branch=var["model_provenance_git_branch"],
            git_commit=var["model_provenance_git_commit"],
            repository_url=var["model_provenance_repository_url"],
            script_dir=var["model_provenance_script_dir"],
            training_id=oci_datascience_training["test_training"]["id"],
            training_script=var["model_provenance_training_script"])
        ```

        ## Import

        ModelProvenances can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:DataScience/modelProvenance:ModelProvenance test_model_provenance "models/{modelId}/provenance"
        ```

        :param str resource_name: The name of the resource.
        :param ModelProvenanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ModelProvenanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 git_branch: Optional[pulumi.Input[str]] = None,
                 git_commit: Optional[pulumi.Input[str]] = None,
                 model_id: Optional[pulumi.Input[str]] = None,
                 repository_url: Optional[pulumi.Input[str]] = None,
                 script_dir: Optional[pulumi.Input[str]] = None,
                 training_id: Optional[pulumi.Input[str]] = None,
                 training_script: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ModelProvenanceArgs.__new__(ModelProvenanceArgs)

            __props__.__dict__["git_branch"] = git_branch
            __props__.__dict__["git_commit"] = git_commit
            if model_id is None and not opts.urn:
                raise TypeError("Missing required property 'model_id'")
            __props__.__dict__["model_id"] = model_id
            __props__.__dict__["repository_url"] = repository_url
            __props__.__dict__["script_dir"] = script_dir
            __props__.__dict__["training_id"] = training_id
            __props__.__dict__["training_script"] = training_script
        super(ModelProvenance, __self__).__init__(
            'oci:DataScience/modelProvenance:ModelProvenance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            git_branch: Optional[pulumi.Input[str]] = None,
            git_commit: Optional[pulumi.Input[str]] = None,
            model_id: Optional[pulumi.Input[str]] = None,
            repository_url: Optional[pulumi.Input[str]] = None,
            script_dir: Optional[pulumi.Input[str]] = None,
            training_id: Optional[pulumi.Input[str]] = None,
            training_script: Optional[pulumi.Input[str]] = None) -> 'ModelProvenance':
        """
        Get an existing ModelProvenance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] git_branch: (Updatable) For model reproducibility purposes. Branch of the git repository associated with model training.
        :param pulumi.Input[str] git_commit: (Updatable) For model reproducibility purposes. Commit ID of the git repository associated with model training.
        :param pulumi.Input[str] model_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the model.
        :param pulumi.Input[str] repository_url: (Updatable) For model reproducibility purposes. URL of the git repository associated with model training.
        :param pulumi.Input[str] script_dir: (Updatable) For model reproducibility purposes. Path to model artifacts.
        :param pulumi.Input[str] training_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of a training session(Job or NotebookSession) in which the model was trained. It is used for model reproducibility purposes.
        :param pulumi.Input[str] training_script: (Updatable) For model reproducibility purposes. Path to the python script or notebook in which the model was trained." 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ModelProvenanceState.__new__(_ModelProvenanceState)

        __props__.__dict__["git_branch"] = git_branch
        __props__.__dict__["git_commit"] = git_commit
        __props__.__dict__["model_id"] = model_id
        __props__.__dict__["repository_url"] = repository_url
        __props__.__dict__["script_dir"] = script_dir
        __props__.__dict__["training_id"] = training_id
        __props__.__dict__["training_script"] = training_script
        return ModelProvenance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="gitBranch")
    def git_branch(self) -> pulumi.Output[str]:
        """
        (Updatable) For model reproducibility purposes. Branch of the git repository associated with model training.
        """
        return pulumi.get(self, "git_branch")

    @property
    @pulumi.getter(name="gitCommit")
    def git_commit(self) -> pulumi.Output[str]:
        """
        (Updatable) For model reproducibility purposes. Commit ID of the git repository associated with model training.
        """
        return pulumi.get(self, "git_commit")

    @property
    @pulumi.getter(name="modelId")
    def model_id(self) -> pulumi.Output[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the model.
        """
        return pulumi.get(self, "model_id")

    @property
    @pulumi.getter(name="repositoryUrl")
    def repository_url(self) -> pulumi.Output[str]:
        """
        (Updatable) For model reproducibility purposes. URL of the git repository associated with model training.
        """
        return pulumi.get(self, "repository_url")

    @property
    @pulumi.getter(name="scriptDir")
    def script_dir(self) -> pulumi.Output[str]:
        """
        (Updatable) For model reproducibility purposes. Path to model artifacts.
        """
        return pulumi.get(self, "script_dir")

    @property
    @pulumi.getter(name="trainingId")
    def training_id(self) -> pulumi.Output[str]:
        """
        (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of a training session(Job or NotebookSession) in which the model was trained. It is used for model reproducibility purposes.
        """
        return pulumi.get(self, "training_id")

    @property
    @pulumi.getter(name="trainingScript")
    def training_script(self) -> pulumi.Output[str]:
        """
        (Updatable) For model reproducibility purposes. Path to the python script or notebook in which the model was trained." 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "training_script")

